
// -----------
// This file was generated by riscv_ctg (https://gitlab.com/incoresemi/riscv-compliance/riscv_ctg)
// version   : 0.4.1
// timestamp : Tue Dec 15 15:36:11 2020 GMT
// usage     : riscv_ctg \
//                  -- cgf ('/scratch/git-repo/incoresemi/riscv-compliance/riscv_ctg/sample_cgfs/dataset.cgf', '/scratch/git-repo/incoresemi/riscv-compliance/riscv_ctg/sample_cgfs/rv32i.cgf') \
//                  -- xlen 32 \
// -----------
//
// -----------
// Copyright (c) 2020. RISC-V International. All rights reserved.
// SPDX-License-Identifier: BSD-3-Clause
// -----------
//
// This assembly file tests the lui instruction of the RISC-V I extension for the lui covergroup.
// 
#include "model_test.h"
#include "arch_test.h"
RVTEST_ISA("RV32I")

.section .text.init
.globl rvtest_entry_point
rvtest_entry_point:
RVMODEL_BOOT
RVTEST_CODE_BEGIN

#ifdef TEST_CASE_1

RVTEST_CASE(0,"//check ISA:=regex(.*32.*);check ISA:=regex(.*I.*);def TEST_CASE_1=True;",lui)

RVTEST_SIGBASE( x9,signature_x9_1)

inst_0:
// rd==x8, imm_val == 0, imm_val==0
// opcode: lui ; dest:x8; immval:0x0
TEST_CASE(x7, x8, 0x0, x9, 0, lui x8,0x0)

inst_1:
// rd==x5, imm_val > 0, imm_val==5
// opcode: lui ; dest:x5; immval:0x5
TEST_CASE(x7, x5, 0x5000, x9, 4, lui x5,0x5)

inst_2:
// rd==x19, imm_val == ((2**20)-1), 
// opcode: lui ; dest:x19; immval:0xfffff
TEST_CASE(x7, x19, -0x1000, x9, 8, lui x19,0xfffff)

inst_3:
// rd==x13, imm_val==3, 
// opcode: lui ; dest:x13; immval:0x3
TEST_CASE(x7, x13, 0x3000, x9, 12, lui x13,0x3)

inst_4:
// rd==x0, imm_val==349525, imm_val == 349525
// opcode: lui ; dest:x0; immval:0x55555
TEST_CASE(x7, x0, 0, x9, 16, lui x0,0x55555)

inst_5:
// rd==x4, imm_val==699050, imm_val == 699050
// opcode: lui ; dest:x4; immval:0xaaaaa
TEST_CASE(x7, x4, -0x55556000, x9, 20, lui x4,0xaaaaa)

inst_6:
// rd==x22, imm_val==209715, 
// opcode: lui ; dest:x22; immval:0x33333
TEST_CASE(x7, x22, 0x33333000, x9, 24, lui x22,0x33333)

inst_7:
// rd==x26, imm_val==419430, 
// opcode: lui ; dest:x26; immval:0x66666
TEST_CASE(x7, x26, 0x66666000, x9, 28, lui x26,0x66666)

inst_8:
// rd==x29, imm_val==724, 
// opcode: lui ; dest:x29; immval:0x2d4
TEST_CASE(x7, x29, 0x2d4000, x9, 32, lui x29,0x2d4)

inst_9:
// rd==x3, imm_val==1023, 
// opcode: lui ; dest:x3; immval:0x3ff
TEST_CASE(x7, x3, 0x3ff000, x9, 36, lui x3,0x3ff)

inst_10:
// rd==x30, imm_val==2, imm_val == 2
// opcode: lui ; dest:x30; immval:0x2
TEST_CASE(x7, x30, 0x2000, x9, 40, lui x30,0x2)

inst_11:
// rd==x16, imm_val==349524, 
// opcode: lui ; dest:x16; immval:0x55554
TEST_CASE(x7, x16, 0x55554000, x9, 44, lui x16,0x55554)

inst_12:
// rd==x2, imm_val==699049, 
// opcode: lui ; dest:x2; immval:0xaaaa9
TEST_CASE(x7, x2, -0x55557000, x9, 48, lui x2,0xaaaa9)

inst_13:
// rd==x24, imm_val==4, imm_val == 4
// opcode: lui ; dest:x24; immval:0x4
TEST_CASE(x7, x24, 0x4000, x9, 52, lui x24,0x4)

inst_14:
// rd==x27, imm_val==209714, 
// opcode: lui ; dest:x27; immval:0x33332
TEST_CASE(x7, x27, 0x33332000, x9, 56, lui x27,0x33332)

inst_15:
// rd==x20, imm_val==419429, 
// opcode: lui ; dest:x20; immval:0x66665
TEST_CASE(x7, x20, 0x66665000, x9, 60, lui x20,0x66665)

inst_16:
// rd==x28, imm_val==723, 
// opcode: lui ; dest:x28; immval:0x2d3
TEST_CASE(x7, x28, 0x2d3000, x9, 64, lui x28,0x2d3)

inst_17:
// rd==x6, imm_val==1022, 
// opcode: lui ; dest:x6; immval:0x3fe
TEST_CASE(x7, x6, 0x3fe000, x9, 68, lui x6,0x3fe)

inst_18:
// rd==x10, imm_val==349526, 
// opcode: lui ; dest:x10; immval:0x55556
TEST_CASE(x7, x10, 0x55556000, x9, 72, lui x10,0x55556)

inst_19:
// rd==x12, imm_val==699051, 
// opcode: lui ; dest:x12; immval:0xaaaab
TEST_CASE(x7, x12, -0x55555000, x9, 76, lui x12,0xaaaab)

inst_20:
// rd==x15, imm_val==6, 
// opcode: lui ; dest:x15; immval:0x6
TEST_CASE(x7, x15, 0x6000, x9, 80, lui x15,0x6)

inst_21:
// rd==x23, imm_val==209716, 
// opcode: lui ; dest:x23; immval:0x33334
TEST_CASE(x7, x23, 0x33334000, x9, 84, lui x23,0x33334)

inst_22:
// rd==x1, imm_val==419431, 
// opcode: lui ; dest:x1; immval:0x66667
TEST_CASE(x7, x1, 0x66667000, x9, 88, lui x1,0x66667)

inst_23:
// rd==x18, imm_val==725, 
// opcode: lui ; dest:x18; immval:0x2d5
TEST_CASE(x7, x18, 0x2d5000, x9, 92, lui x18,0x2d5)

inst_24:
// rd==x11, imm_val==1, imm_val == 1
// opcode: lui ; dest:x11; immval:0x1
TEST_CASE(x7, x11, 0x1000, x9, 96, lui x11,0x1)

inst_25:
// rd==x21, imm_val==1024, imm_val == 1024
// opcode: lui ; dest:x21; immval:0x400
TEST_CASE(x7, x21, 0x400000, x9, 100, lui x21,0x400)

inst_26:
// rd==x17, imm_val == 8, 
// opcode: lui ; dest:x17; immval:0x8
TEST_CASE(x7, x17, 0x8000, x9, 104, lui x17,0x8)

inst_27:
// rd==x25, imm_val == 16, 
// opcode: lui ; dest:x25; immval:0x10
TEST_CASE(x7, x25, 0x10000, x9, 108, lui x25,0x10)

inst_28:
// rd==x7, imm_val == 32, 
// opcode: lui ; dest:x7; immval:0x20
TEST_CASE(x2, x7, 0x20000, x9, 112, lui x7,0x20)
RVTEST_SIGBASE( x1,signature_x1_0)

inst_29:
// rd==x14, imm_val == 64, 
// opcode: lui ; dest:x14; immval:0x40
TEST_CASE(x2, x14, 0x40000, x1, 0, lui x14,0x40)

inst_30:
// rd==x9, imm_val == 128, 
// opcode: lui ; dest:x9; immval:0x80
TEST_CASE(x2, x9, 0x80000, x1, 4, lui x9,0x80)

inst_31:
// rd==x31, imm_val == 983039, 
// opcode: lui ; dest:x31; immval:0xeffff
TEST_CASE(x2, x31, -0x10001000, x1, 8, lui x31,0xeffff)

inst_32:
// imm_val == 917503, 
// opcode: lui ; dest:x10; immval:0xdffff
TEST_CASE(x2, x10, -0x20001000, x1, 12, lui x10,0xdffff)

inst_33:
// imm_val == 786431, 
// opcode: lui ; dest:x10; immval:0xbffff
TEST_CASE(x2, x10, -0x40001000, x1, 16, lui x10,0xbffff)

inst_34:
// imm_val == 524287, 
// opcode: lui ; dest:x10; immval:0x7ffff
TEST_CASE(x2, x10, 0x7ffff000, x1, 20, lui x10,0x7ffff)

inst_35:
// imm_val == 256, 
// opcode: lui ; dest:x10; immval:0x100
TEST_CASE(x2, x10, 0x100000, x1, 24, lui x10,0x100)

inst_36:
// imm_val == 512, 
// opcode: lui ; dest:x10; immval:0x200
TEST_CASE(x2, x10, 0x200000, x1, 28, lui x10,0x200)

inst_37:
// imm_val == 2048, 
// opcode: lui ; dest:x10; immval:0x800
TEST_CASE(x2, x10, 0x800000, x1, 32, lui x10,0x800)

inst_38:
// imm_val == 4096, 
// opcode: lui ; dest:x10; immval:0x1000
TEST_CASE(x2, x10, 0x1000000, x1, 36, lui x10,0x1000)

inst_39:
// imm_val == 8192, 
// opcode: lui ; dest:x10; immval:0x2000
TEST_CASE(x2, x10, 0x2000000, x1, 40, lui x10,0x2000)

inst_40:
// imm_val == 16384, 
// opcode: lui ; dest:x10; immval:0x4000
TEST_CASE(x2, x10, 0x4000000, x1, 44, lui x10,0x4000)

inst_41:
// imm_val == 32768, 
// opcode: lui ; dest:x10; immval:0x8000
TEST_CASE(x2, x10, 0x8000000, x1, 48, lui x10,0x8000)

inst_42:
// imm_val == 65536, 
// opcode: lui ; dest:x10; immval:0x10000
TEST_CASE(x2, x10, 0x10000000, x1, 52, lui x10,0x10000)

inst_43:
// imm_val == 131072, 
// opcode: lui ; dest:x10; immval:0x20000
TEST_CASE(x2, x10, 0x20000000, x1, 56, lui x10,0x20000)

inst_44:
// imm_val == 262144, 
// opcode: lui ; dest:x10; immval:0x40000
TEST_CASE(x2, x10, 0x40000000, x1, 60, lui x10,0x40000)

inst_45:
// imm_val == 524288, 
// opcode: lui ; dest:x10; immval:0x80000
TEST_CASE(x2, x10, -0x80000000, x1, 64, lui x10,0x80000)

inst_46:
// imm_val == 1048574, 
// opcode: lui ; dest:x10; immval:0xffffe
TEST_CASE(x2, x10, -0x2000, x1, 68, lui x10,0xffffe)

inst_47:
// imm_val == 1048573, 
// opcode: lui ; dest:x10; immval:0xffffd
TEST_CASE(x2, x10, -0x3000, x1, 72, lui x10,0xffffd)

inst_48:
// imm_val == 1048571, 
// opcode: lui ; dest:x10; immval:0xffffb
TEST_CASE(x2, x10, -0x5000, x1, 76, lui x10,0xffffb)

inst_49:
// imm_val == 1048567, 
// opcode: lui ; dest:x10; immval:0xffff7
TEST_CASE(x2, x10, -0x9000, x1, 80, lui x10,0xffff7)

inst_50:
// imm_val == 1048559, 
// opcode: lui ; dest:x10; immval:0xfffef
TEST_CASE(x2, x10, -0x11000, x1, 84, lui x10,0xfffef)

inst_51:
// imm_val == 1048543, 
// opcode: lui ; dest:x10; immval:0xfffdf
TEST_CASE(x2, x10, -0x21000, x1, 88, lui x10,0xfffdf)

inst_52:
// imm_val == 1048511, 
// opcode: lui ; dest:x10; immval:0xfffbf
TEST_CASE(x2, x10, -0x41000, x1, 92, lui x10,0xfffbf)

inst_53:
// imm_val == 1048447, 
// opcode: lui ; dest:x10; immval:0xfff7f
TEST_CASE(x2, x10, -0x81000, x1, 96, lui x10,0xfff7f)

inst_54:
// imm_val == 1048319, 
// opcode: lui ; dest:x10; immval:0xffeff
TEST_CASE(x2, x10, -0x101000, x1, 100, lui x10,0xffeff)

inst_55:
// imm_val == 1048063, 
// opcode: lui ; dest:x10; immval:0xffdff
TEST_CASE(x2, x10, -0x201000, x1, 104, lui x10,0xffdff)

inst_56:
// imm_val == 1047551, 
// opcode: lui ; dest:x10; immval:0xffbff
TEST_CASE(x2, x10, -0x401000, x1, 108, lui x10,0xffbff)

inst_57:
// imm_val == 1046527, 
// opcode: lui ; dest:x10; immval:0xff7ff
TEST_CASE(x2, x10, -0x801000, x1, 112, lui x10,0xff7ff)

inst_58:
// imm_val == 1044479, 
// opcode: lui ; dest:x10; immval:0xfefff
TEST_CASE(x2, x10, -0x1001000, x1, 116, lui x10,0xfefff)

inst_59:
// imm_val == 1040383, 
// opcode: lui ; dest:x10; immval:0xfdfff
TEST_CASE(x2, x10, -0x2001000, x1, 120, lui x10,0xfdfff)

inst_60:
// imm_val == 1032191, 
// opcode: lui ; dest:x10; immval:0xfbfff
TEST_CASE(x2, x10, -0x4001000, x1, 124, lui x10,0xfbfff)

inst_61:
// imm_val == 1015807, 
// opcode: lui ; dest:x10; immval:0xf7fff
TEST_CASE(x2, x10, -0x8001000, x1, 128, lui x10,0xf7fff)

inst_62:
// imm_val==349525, imm_val == 349525
// opcode: lui ; dest:x10; immval:0x55555
TEST_CASE(x2, x10, 0x55555000, x1, 132, lui x10,0x55555)
#endif


RVTEST_CODE_END
RVMODEL_HALT

RVTEST_DATA_BEGIN
.align 4
rvtest_data:
.word 0xbabecafe
RVTEST_DATA_END

RVMODEL_DATA_BEGIN


signature_x9_0:
    .fill 0*(XLEN/32),4,0xdeadbeef


signature_x9_1:
    .fill 29*(XLEN/32),4,0xdeadbeef


signature_x1_0:
    .fill 34*(XLEN/32),4,0xdeadbeef

#ifdef rvtest_mtrap_routine

mtrap_sigptr:
    .fill 64*(XLEN/32),4,0xdeadbeef

#endif

#ifdef rvtest_gpr_save

gpr_save:
    .fill 32*(XLEN/32),4,0xdeadbeef

#endif

RVMODEL_DATA_END
